/**
 * @file 封装原生fetch请求
 */
// 引入标准Fetch及IE兼容依赖
import 'whatwg-fetch';
import 'es6-promise/dist/es6-promise.min.js';
import {Modal, message} from 'antd';
message.config({
    duration: 2,
    maxCount: 1
});


const SUCCESS_CODE = 200;

const api = async (url, {loading, ...options}) => {
    loading && window.LoadingObserver && window.LoadingObserver.pub(true);
    try {
        let result = await fetch(url, options).then(res => {
            if (options.buffer) {
                return res;
            }
            // eslint-disable-next-line handle-callback-err
            return res.json().catch(err => {
                // eslint-disable-next-line no-new
                new Error('the response data format is not json');
            });
        });
        if (options.withCode) {
            return result;
        }
        loading && window.LoadingObserver && window.LoadingObserver.pub(false);
        if (Number(result.code) === SUCCESS_CODE) {
            return result;
        }
        else {
            throw new Error(result.message);
        }
    }
    catch (error) {
        loading && window.LoadingObserver && window.LoadingObserver.pub(false);
        if (options.useModal) {
            Modal.error({
                title: '错误提示!',
                content: error.message || '网络异常！'
            });
        }
        else {
            message.error(error.message || '网络异常！');
        }
        throw error;
    }

};

export default {
    postJson: (url, json, useModal) => api(url, {
        method: 'post',
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json'
        },
        credentials: 'include',
        body: json ? JSON.stringify(json) : null,
        useModal: useModal
    }),

    postJsonWithflag: (url, json, useModal) => api(url, {
        method: 'post',
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json'
        },
        credentials: 'include',
        body: JSON.stringify(json),
        flag: true,
        useModal: useModal
    }),

    postJsonCode: (url, json, useModal) => api(url, {
        method: 'post',
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json'
        },
        credentials: 'include',
        withCode: true,
        body: json ? JSON.stringify(json) : null,
        useModal: useModal
    }),

    postFormData: (url, formData, useModal) => api(url, {
        method: 'post',
        credentials: 'include',
        body: formData,
        useModal: useModal
    }),

    postFormDataCode: (url, formData, useModal) => api(url, {
        method: 'post',
        credentials: 'include',
        body: formData,
        withCode: true,
        useModal: useModal
    }),

    get: (url, useModal) => api(url, {
        method: 'get',
        credentials: 'include',
        useModal: useModal
    }),

    getWithflag: (url, useModal) => api(url, {
        method: 'get',
        flag: true,
        credentials: 'include',
        useModal: useModal
    })
};
