// 存放一些简单的工具函数

export const MaxNum1000 = /^([1-9]\d{0,2}|1000)$/; // 只能输入1-1000的正则

// 判断两个对象是否相等
export function isObjectValueEqual(a, b) {
    let aProps = Object.getOwnPropertyNames(a);
    let bProps = Object.getOwnPropertyNames(b);
    if (aProps.length !== bProps.length) {
        return false;
    }

    for (let i = 0; i < aProps.length; i++) {
        let propName = aProps[i];
        if (a[propName] !== b[propName]) {
            return false;
        }

    }
    return true;
}
// 将对象转换为查询字符串
export function objToQueryStr(obj) {
    let str = [];
    for (let p in obj) {
        if (obj.hasOwnProperty(p)) {
            str.push(encodeURIComponent(p) + '=' + encodeURIComponent(obj[p]));
        }

    }
    return str.join('&');
}

// 将查询字符串转换成对象
export function parseObject(url) {
    let obj = {};
    let keyvalue = [];
    let key = '';
    let value = '';
    let paraString = url.substring(url.indexOf('?') + 1, url.length).split('&');
    // eslint-disable-next-line guard-for-in
    for (let i in paraString) {
        keyvalue = paraString[i].split('=');
        key = keyvalue[0];
        value = keyvalue[1];
        obj[key] = value;
    }
    return obj;
}

// 对象的深拷贝
export function deepCopy(obj) {
    let result = Array.isArray(obj) ? [] : {};
    for (let key in obj) {
        if (obj.hasOwnProperty(key)) {
            if (typeof obj[key] === 'object') {
                result[key] = deepCopy(obj[key]); // 递归复制
            }
            else {
                result[key] = obj[key];
            }
        }

    }
    return result;
}

// 将ES6的map对象转换为json格式
export function mapToJson(mapObj) {
    let json = {};
    for (let [k, v] of mapObj) {
        json[k] = v;
    }
    return json;
}

// 将ES6的map对象转换为Array格式
export function mapToAry(mapObj) {
    let arr = [];
    for (let [k, v] of mapObj) {
        arr.push([k, mapObj[v]]);
    }
    return arr;
}

// 删除数组中的某个对象
export function removeObjInArr(arr, obj) {
    let length = arr.length;
    for (let i = 0; i < length; i++) {
        if (JSON.stringify(arr[i]) === JSON.stringify(obj)) {
            if (i === 0) {
                arr.shift(); // 删除并返回数组的第一个元素
                return arr;
            }
            else if (i === length - 1) {
                arr.pop(); // 删除并返回数组的最后一个元素
                return arr;
            }
            else {
                arr.splice(i, 1); // 删除下标为i的元素
                return arr;
            }
        }

    }
}

// 下划线转换驼峰
export function toHump(name) {
    // eslint-disable-next-line no-useless-escape
    return name.replace(/\_(\w)/g, function (all, letter) {
        return letter.toUpperCase();
    });
}
// 驼峰转换下划线
export function toLine(name) {
    return name.replace(/([A-Z])/g, '_$1').toLowerCase();
}
