/* eslint-disable no-unused-vars */
const webpack = require('webpack');
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const OpenBrowserPlugin = require('open-browser-webpack-plugin');
const merge = require('webpack-merge');
const baseWebpackConfig = require('./webpack.config.base');

// 引入dev-server配置文件
let serverConfig = require('./config/config.server.js');

// 引入接口代理配置文件
const proxyConfig = require('./config/config.proxy.js');

module.exports = merge(baseWebpackConfig, {
    target: 'web',
    mode: 'development',
    devtool: 'cheap-module-source-map',
    devServer: {
        historyApiFallback: true,
        disableHostCheck: true,
        hot: false,
        inline: true,
        contentBase: './src',
        port: serverConfig.port,
        host: serverConfig.host,
        proxy: proxyConfig
    },
    plugins: [
        new HtmlWebpackPlugin(
            {
                filename: 'index.html',
                template: './src/index.html'
            }
        ),
        // 开发环境下自动打开指定网址插件
        new OpenBrowserPlugin({
            url: 'http://' + serverConfig.host + ':' + serverConfig.port
        })
    ]
});
